@@ -3,9 +3,9 @@
 #include <QAction>
 #include <QCheckBox>
 #include <QComboBox>
-#include <QMainWindow>
 #include <QDialog>
 #include <QGridLayout>
+#include <QMainWindow>
 #include <QSpinBox>
 
 #include <obs-frontend-api.h>
@@ -13,13 +13,14 @@
 class TransitionTableDialog : public QDialog {
 	Q_OBJECT
 	QGridLayout *mainLayout;
+	QComboBox *canvasCombo;
 	QComboBox *fromCombo;
 	QComboBox *toCombo;
 	QComboBox *transitionCombo;
 	QSpinBox *durationSpin;
 
-	struct obs_frontend_source_list scenes = {};
-	struct obs_frontend_source_list transitions = {};
+	//struct obs_frontend_source_list scenes = {};
+	//struct obs_frontend_source_list transitions = {};
 	void AddClicked();
 	void DeleteClicked();
 	void SelectAllChanged();
